@@ -1,5 +1,5 @@
 # prime/engine/engine-alphabet.rb
-# $Id: engine-alphabet.rb,v 1.5 2003/12/09 07:49:51 komatsu Exp $
+# $Id: engine-alphabet.rb,v 1.6 2004/01/09 21:45:57 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -25,7 +25,8 @@ class PrimeEngineAlphabet < PrimeEngine
   def lookup (input, method = :prefix)
     results = PrimeResult.new
 
-    if input.original == input.original.upcase then
+    if input.original == input.original.upcase and
+        input.original != input.original.downcase then
       results << PrimeCandidate.new(input.original.downcase, input.original,
 				    17000, "̤θ") # ñ(ʸ)
     else
