@@ -1,5 +1,5 @@
 # taiyaki.rb: Ruby Libraries by Hiroyuki Komatsu
-# $Id: taiyaki.rb,v 1.3 2003/12/01 07:03:24 komatsu Exp $
+# $Id: taiyaki.rb,v 1.4 2003/12/31 09:21:23 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -8,6 +8,51 @@
 # You can redistribute it and/or modify it under the terms of 
 # the GNU General Public License version 2.
 
+def require (name, package = nil, url = nil)
+  package_name =
+         {'progressbar'                => 'progressbar',
+          'sary'                       => 'sary-ruby',
+          'prime/prime-dict-config.rb' => 'prime-dict',
+          'suikyo/suikyo'              => 'suikyo',
+  }
+  package_url =
+         {'progressbar'   => 'http://www.namazu.org/~satoru/ruby-progressbar/',
+          'sary'          => 'http://sary.namazu.org/',
+          'prime/prime-dict-config.rb' =>
+                             'http://sourceforge.jp/projects/prime/',
+          'suikyo/suikyo' => 'http://taiyaki.org/suikyo/',
+  }
+  begin
+    Kernel::require(name)
+  rescue LoadError
+    package = (package or package_name[name])
+    url     = (url     or package_url[name])
+
+    $stderr.puts("ERROR:")
+    if ENV['LANG'] == 'ja_JP.eucJP' then
+      $stderr.puts("  Ruby 饤֥ '#{name}' ɤǤޤǤ")
+      if package then
+        $stderr.puts("  餯 #{package} ѥå" +
+                     "󥹥ȡ뤹ɬפޤ")
+      end
+      if url then
+        $stderr.puts("    <#{url}>")
+      end
+      $stderr.puts("  򤪤Ƥߤޤ")
+    else
+      $stderr.puts("  The required Ruby library '#{name}' is not found.")
+      if package then
+        $stderr.puts("  You might need to install a #{package} package.")
+      end
+      if url then
+        $stderr.puts("    <#{url}>")
+      end
+      $stderr.puts("  Sorry for your inconvenience.")
+    end
+    exit()
+  end
+end
+
 def with_io(io, option = "w")
   ### with_io('/tmp/logfile') {|io|
   ###   lines.each {|line|
@@ -41,10 +86,10 @@ end
 
 
 class String
-  # '$B$!(B-$B$s(B'
+  # '-'
   HIRAGANA_SJIS = "\202\237-\202\361"
   HIRAGANA_EUC  = "\244\241-\244\363"
-  # '$B%!(B-$B%s(B'
+  # '-'
   KATAKANA_SJIS = "\203@-\203\223"
   KATAKANA_EUC  = "\245\241-\245\363"
 
@@ -114,6 +159,15 @@ class File
     return paths.join(File::Separator)
   end
   # Check delext("text.txt")
+
+  def File::ensure (file, filemode = nil)
+    if File::file?(file) == false then
+      File::open(file, "w").close()
+    end
+    if filemode then
+      File::chmod(filemode, file)
+    end
+  end
 end
 
 class Dir
